@@ -36,6 +36,10 @@
 typedef std::map<std::string, int> strintmap_t;
 
 class ModMap : public strintmap_t {
+private:
+   DLLLOCAL ModMap(const ModMap &);
+   DLLLOCAL ModMap& operator=(const ModMap&);
+
 public:
    DLLLOCAL ModMap() {
       insert(ModMap::value_type("add", LDAP_MOD_ADD));
@@ -43,6 +47,9 @@ public:
       insert(ModMap::value_type("replace", LDAP_MOD_REPLACE));
    }
 
+   DLLLOCAL ~ModMap() {
+   }
+
    DLLLOCAL int get(const char* mod) const {
       const ModMap::const_iterator i = find(mod);
       return i == end() ? -1 : i->second;
